---
jupytext:
  text_representation:
    extension: .md
    format_name: myst
    format_version: 0.12
    jupytext_version: 1.9.1
kernelspec:
  display_name: Python 3
  language: python
  name: python3
---

```{currentmodule} tskit
```

(sec_cli)=

# Command line interface

```{eval-rst}
.. argparse::
    :module: tskit.cli
    :func: get_tskit_parser
    :prog: python3 -m tskit
```